/// A TimeUnit represents time durations at a given unit of granularity and provides utility methods 
/// to convert across units, and to perform timing and delay operations in these units. 
/// A TimeUnit does not maintain time information, but only helps organize and use time representations 
/// that may be maintained separately across various contexts. A nanosecond is defined as one thousandth of a microsecond, 
/// a microsecond as one thousandth of a millisecond, a millisecond as one thousandth of a second, a minute as sixty seconds, 
/// an hour as sixty minutes, and a day as twenty four hours.

enum TimeUnit {
  /// Time unit representing twenty four hours
  days,

  /// Time unit representing sixty minutes

  hours,

  /// Time unit representing one thousandth of a millisecond
  microseconds,

  /// Time unit representing one thousandth of a second

  milliseconds,

  /// Time unit representing sixty seconds
  minutes,

  /// Time unit representing one thousandth of a microsecond
  nanoseconds,

  /// Time unit representing one second
  seconds,
}
